@@ -6,7 +6,7 @@ package Dist::Iller::Config::Author::CSSON;
 
 # ABSTRACT: Dist::Iller config
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0306';
+our $VERSION = '0.0307';
 
 use Moose;
 use namespace::autoclean;
@@ -65,6 +65,13 @@ has splint => (
         1 => q{Include Pod::Elemental::Transformer::Splint in weaver.ini},
     }
 );
+has badges => (
+    is => 'ro',
+    isa => Bool,
+    default => 1,
+    documentation => 'Include Badge::Depot badges or not.',
+);
+
 has travis => (
     is => 'rw',
     isa => Int,
@@ -145,22 +152,21 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-42.7%-red.svg" alt="coverage 42.7%" /></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-Config-Author-CSSON-0.0307"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller-Config-Author-CSSON/0.0307" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0307"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0307" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-42.7%-red.svg" alt="coverage 42.7%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.10+](https://img.shields.io/badge/perl-5.10+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON) ![coverage 42.7%](https://img.shields.io/badge/coverage-42.7%-red.svg)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.0306, released 2016-02-15.
+Version 0.0307, released 2016-02-18.
 
 
 
@@ -278,6 +284,36 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
 
 =end markdown
 
+=head2 badges
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Bool">Bool</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Include Badge::Depot badges or not.</p>
+
+=end HTML
+
+=begin markdown
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Bool">Bool</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Include Badge::Depot badges or not.</p>
+
+=end markdown
+
 =head2 filepath
 
 =begin HTML
